{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Policies" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Policy Library") %}
{% endblock page_header %}

{% block main %}
  <div id="library">
    {{policy_library_table.render}}
{% endblock %}
