{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Data Sources" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Data Sources") %}
{% endblock page_header %}

{% block main %}
  <div id="datasources_list_tables">
    {{ datasources_list_table.render }}
  </div>
  <div id="service_status_tables">
    {{ service_status_table.render }}
  </div>
{% endblock %}
