{% extends 'base.html' %}

{% block css %}
  {% include "_stylesheets.html" %}

  {% load compress %}
  {% compress css %}
    <link href='{{ STATIC_URL }}admin/css/policies.css' type='text/css' media='screen' rel='stylesheet' />
  {% endcompress %}
{% endblock %}

{% block js %}
  {% include "admin/_scripts.html" %}
{% endblock %}
