{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Data Source Table Details" %}{% endblock %}

{% block page_header %}
   {% include "horizon/common/_page_header.html" with title=_("Data Source Table Details: ")|add:table_name %}
{% endblock page_header %}

{% block main %}
  {% include "admin/datasources/_detail_overview.html" %}
  <div id="datasource_table_rows">
    {{ datasource_rows_table.render }}
  </div>
{% endblock %}
