<tr id="mapping_{{ count }}" class="{% if count == 0 %}hidden{% else %}mapping-row{% endif %}">
  <td class="borderless label-cell">
    {% if count <= 1 %}<div class="form-group{% if count == 1 and form.mappings.errors %} has-error{% endif %} {{ form.mappings.css_classes }}">
      <label class="control-label{% if form.mappings.field.required %} {{ form.required_css_class }}{% endif %}" for="policy_columns">{{ form.mappings.label }}</label>
      {% if form.mappings.help_text %}
        <span class="help-icon" data-toggle="tooltip" data-placement="top" title="{{ form.mappings.help_text|safe }}"><span class="fa fa-question-circle"></span></span>
      {% endif %}
    </div>{% endif %}
  </td>
  <td class="borderless policy-column-name">{{ column }}</td>
  <td class="borderless mapping-text">maps to</td>
  <td class="ui-front borderless input-cell">
    <div class="has-feedback ac">
      <input id="mapping_column_{{ count }}" class="form-control ac-columns mapping-column-input" name="mapping_column_{{ count }}" type="text" placeholder="e.g. nova:servers name" value="{{ value }}" />
      <div class="form-control-feedback">
        <span class="caret"></span>
      </div>
    </div>
  </td>
  <td class="borderless"></td>
</tr>
