/* tables */
#policy_columns_table {
  margin-bottom: 5px;
}
#policy_columns_table td.input-cell {
  width: 94%;
  padding-left: 0;
}
#policy_columns_table td.button-cell {
  padding: 0;
  text-align: right;
}

#policy_columns_table td.input-errors,
#mappings_table td.input-errors {
  padding: 0;
}
#policy_columns_table td.borderless,
#mappings_table td.borderless,
#joins_table td.borderless,
#negations_table td.borderless,
#aliases_table td.borderless {
  border: none;
}
#mappings_table td.input-cell,
#joins_table td.input-cell,
#negations_table td.input-cell,
#aliases_table td.input-cell {
  width: 36%;
}

#mappings_table td.label-cell {
  width: 22%;
}
#mappings_table td.policy-column-name {
  width: 28%;
  text-align: right;
  font-style: italic;
}
#mappings_table td.mapping-text {
  width: 10%;
  text-align: center;
}

#joins_table,
#negations_table,
#aliases_table {
  margin-top: 30px;
  margin-bottom: 5px;
}
#joins_table td.operator-cell,
#negations_table td.operator-cell {
  width: 24%;
  text-align: center;
}

#aliases_table td.label-cell {
  width: 19%;
}
#aliases_table td.alias-text {
  width: 5%;
  text-align: center;
}

/* forms */
#mappings_table div.form-group,
#joins_table div.form-group,
#negations_table div.form-group,
#aliases_table div.form-group {
  margin-bottom: 0;
}
#mappings_table input.form-control,
#joins_table input.form-control,
#negations_table input.form-control,
#aliases_table input.form-control {
  padding-right: 36px;
}
#mappings_table div.form-control-feedback,
#joins_table div.form-control-feedback,
#negations_table div.form-control-feedback,
#aliases_table div.form-control-feedback {
  background-color: #DDDDDD;
  width: 20px;
  height: 24px;
  top: 5px;
  right: 5px;
}
#mappings_table span.caret,
#joins_table span.caret,
#negations_table span.caret,
#aliases_table span.caret {
  border-width: 5px;
  color: #333333;
  margin-bottom: 10px;
}
#add_join_button,
#add_negation_button,
#add_alias_button {
  margin-left: 5px;
}


/* autocompletion */
.ui-autocomplete {
  max-height: 200px;
  overflow-y: auto;
  /* prevent horizontal scrollbar */
  overflow-x: hidden;
}
/* IE 6 doesn't support max-height
 * we use height instead, but this forces the menu to always be this tall
 */
* html .ui-autocomplete {
  height: 200px;
}
.ui-widget {
  font-family: inherit;
  font-size: inherit;
}
.ui-state-hover,
.ui-widget-content .ui-state-hover,
.ui-widget-header .ui-state-hover,
.ui-state-focus,
.ui-widget-content .ui-state-focus,
.ui-widget-header .ui-state-focus,
.ui-state-active,
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active {
  border: 1px solid #285e8e;
  background: none;
  background-color: #3276b1;
  font-weight: normal;
  color: #ffffff;
}
