{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Policy Details" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Policy Details: ")|add:policy.name %}
{% endblock page_header %}

{% block main %}
  {% include "admin/policies/_detail_overview.html" %}
  <hr>
  <div id="policy_rules">
    {{ policy_rules_table.render }}
  </div>
  <div id="policies_tables">
    {{ policies_tables_table.render }}
  </div>
  <span id="ds_tables" class="hidden">{{ tables }}</span>
  <span id="ds_columns" class="hidden">{{ columns }}</span>
{% endblock %}
